@@ -1,58 +1,51 @@
-#Author: AIMPED
-#Date: 2023-March-20
-#Description: Contains the translation functions for aimped library.
+import re
+from nltk.tokenize import sent_tokenize
 
-def language_code(language):
-    languages = {
-    "Mandarin Chinese": "zh",
-    "Spanish": "es",
-    "English": "en",
-    "Hindi": "hi",
-    "Arabic": "ar",
-    "Bengali": "bn",
-    "Portuguese": "pt",
-    "Russian": "ru",
-    "Japanese": "ja",
-    "Punjabi": "pa",
-    "German": "de",
-    "Javanese": "jv",
-    "Wu Chinese": "wuu",
-    "Malay": "ms",
-    "Telugu": "te",
-    "Vietnamese": "vi",
-    "Korean": "ko",
-    "French": "fr",
-    "Marathi": "mr",
-    "Tamil": "ta",
-    "Urdu": "ur",
-    "Turkish": "tr",
-    "Italian": "it",
-    "Yue Chinese": "yue",
-    "Thai": "th",
-    "Gujarati": "gu",
-    "Jin Chinese": "cjy",
-    "Persian": "fa",
-    "Polish": "pl",
-    "Pashto": "ps"
-}
-    return languages[language]
 
-def split_text(text, source_language, input_length=64):
+
+def split_text(text, source_lang, input_length=64):
     """
     Splits the input text into sentences and creates batches of sentences to be fed into the model.
 
     Args:
         text (str): The input text to be split into sentences.
+        source_lang (str): The language of the input text.
+        language_codes (dict): A dictionary mapping language names to their corresponding language codes.
+        input_length (int): The maximum number of tokens in a batch.
 
     Returns:
         A list of lists, where each inner list contains a batch of sentences. Each batch is represented as a list of strings.
     """        
-    from nltk import sent_tokenize
 
+    language_codes = {
+        "en": "english",
+        "de": "german",
+        "fr": "french",
+        "es": "spanish",
+        "it": "italian",
+        "nl": "dutch",
+        "pl": "polish",
+        "pt": "portuguese",
+        "tr": "turkish",
+        "ru": "russian",
+        "ar": "arabic",
+        "zh": "chinese",
+        "ja": "japanese",
+        "ko": "korean",
+        "vi": "vietnamese",
+        "th": "thai",
+        "hi": "hindi",
+        "bn": "bengali",
+                     }
+    
     paragraphs = text.split("\n")
-    sentenced_paragraphs = [sent_tokenize(paragraph, language=source_language) if paragraph else ['<p>--</p>'] for paragraph in paragraphs]
+    if source_lang == "zh":
+        sentenced_paragraphs = [re.split(r'[。！？]', paragraph) if paragraph else ['<p>'] for paragraph in paragraphs]
+        return sentenced_paragraphs
+
+    else:    
+        sentenced_paragraphs = [sent_tokenize(paragraph, language=language_codes[source_lang]) if paragraph else ['<p>--</p>'] for paragraph in paragraphs]
     input_paragraphs = [" ".join([sentence + " end_of_sentence" for sentence in sentences]) for sentences in sentenced_paragraphs]
-            
 
     input_sentences = []
     for input_paragraph in input_paragraphs:
@@ -78,25 +71,27 @@ def split_text(text, source_language, input_length=64):
         input_sentences.append(temp)
     return input_sentences
 
-def translate(text, source_language, pipeline):
-    
+def translate_text(input_texts_list,pipeline):
     """
+    Translates a list of texts into the target language using a given pipeline function and split text function.
+
     Args:
         text (list of str): A list of texts to be translated.
+        split_text_fn (function): A function that splits the input text into sentences and creates batches of sentences to be fed into the model.
+        pipeline_fn (function): A function that takes a list of input texts and returns a list of dictionaries containing the translations.
+
     Returns:
         translated_texts (list of str): A list of translated texts in the target language. 
         The order of the texts in the output list corresponds to the order of the input texts in the text parameter.
     """
-    input_texts_list = [split_text(input_text, source_language=source_language) for input_text in text]
+    
     translated_texts = []
     for input_texts in input_texts_list:
-    # Translate each input chunk and combine the translated chunks into the final translated text
+        # Translate each input chunk and combine the translated chunks into the final translated text
         output_texts = []
         for texts in input_texts:
-            # print(texts)
             translation_result = pipeline(texts)
-            # translated_result = [result["translation_text"] for result in translation_result]
             translated_result = [result["translation_text"] for result in translation_result]
             output_texts.append(" ".join(translated_result))
-        translated_texts.append("\n".join(output_texts).replace("<p>--</p>", ""))
+        translated_texts.append("\n".join(output_texts).replace("<p>--</p>", "").replace("<p>", ""))
     return translated_texts
